﻿using GalaSoft.MvvmLight;
using System.ComponentModel;
using System.Collections.ObjectModel;
using GalaSoft.MvvmLight.Command;
using Infragistics.Windows.DataPresenter;

namespace MvvmLight1.ViewModel
{
    /// <summary>
    /// This class contains properties that the main View can data bind to.
    /// <para>
    /// Use the <strong>mvvminpc</strong> snippet to add bindable properties to this ViewModel.
    /// </para>
    /// <para>
    /// You can also use Blend to data bind with the tool's support.
    /// </para>
    /// <para>
    /// See http://www.galasoft.ch/mvvm/getstarted
    /// </para>
    /// </summary>
    public class MainViewModel : ViewModelBase
    {
        public RelayCommand<object> IncreaseCommand 
        { 
            get; 
            private set; 
        }

        private ObservableCollection<MyClass> sampleData;
        public ObservableCollection<MyClass> SampleData
        {
            get { return sampleData; }
            set 
            { 
                sampleData = value;
                RaisePropertyChanged("SampleData");
            }
        }

        public MainViewModel()
        {
            if (IsInDesignMode)
            {
                // Code runs in Blend --> create design time data.
            }
            else
            {
                sampleData = new ObservableCollection<MyClass>()
                {
                    new MyClass(){ IntProperty=1, StateProperty=State.Disable},
                    new MyClass(){ IntProperty=5, StateProperty=State.Enable},
                    new MyClass(){ IntProperty=7, StateProperty=State.Disable},
                    new MyClass(){ IntProperty=9, StateProperty=State.Disable}
                };

                IncreaseCommand = new RelayCommand<object>(this.Execute, this.CanExecute); 
                     
                    
            }
        }
        public bool CanExecute(object parameter)
        {
            var record = parameter as DataRecord;			
	        if (record == null)			
	        {				
		        return false;			
	        } 			
	        var item = record.DataItem as MyClass;			
	        if (item == null)			
	        {
                return false;		
	        }
            if (item.StateProperty == State.Disable)
            {
                return false;
            }
	        return true ;
        }
        public void Execute(object parameter)
        {
            var record = parameter as DataRecord;
            var item = record.DataItem as MyClass;
            item.IntProperty++;
        }
    }

    public class MyClass:INotifyPropertyChanged
    {
        private int intProperty;
        private State stateProperty;

        public State StateProperty
        {
            get { return stateProperty; }
            set 
            { 
                stateProperty = value;
                RaisePropertyChanged("StateProperty");
            }
        }
        public int IntProperty
        {
            get { return intProperty; }
            set 
            { 
                intProperty = value;
                RaisePropertyChanged("IntProperty");
            }
        }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;
        protected void RaisePropertyChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }

        #endregion

    }
    public enum State
    {
        Enable,
        Disable
    }
}